# Table of Contents

- [retrieving-diagram-by-id](<./retrieving-diagram-by-id.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Retrieving a Diagram by ID](<./Retrieving-a-Diagram-by-ID.md>)
  - [Retrieving All Diagrams](<./Retrieving-a-Diagram-by-ID/Retrieving-All-Diagrams.md>)
  - [Retrieving a Diagram by ID](<./Retrieving-a-Diagram-by-ID/Retrieving-a-Diagram-by-ID.md>)
